Fides Admin UI - Config Wizard
Description: Generated from FidesUI template

### Get Started

Privacy engineering can seem like an endlessly complex confluence of legal and data engineering terminology - fear not; Fides is here to simplify this. This wizard will help you to very quickly configure Fidesctl and in doing so build your first data map. Along the way you'll learn the basic resources and concepts of privacy engineering with Fides so you can quickly apply in all your work.
Let's get started!